@@ -4,7 +4,7 @@ using ::testing::Action;
 using ::testing::Invoke;
 
 void FuseRmdirTest::Rmdir(const char *dirname) {
-  int error = RmdirReturnError(dirname);
+  const int error = RmdirReturnError(dirname);
   EXPECT_EQ(0, error);
 }
 
@@ -12,7 +12,7 @@ int FuseRmdirTest::RmdirReturnError(const char *dirname) {
   auto fs = TestFS();
 
   auto realpath = fs->mountDir() / dirname;
-  int retval = ::rmdir(realpath.string().c_str());
+  const int retval = ::rmdir(realpath.string().c_str());
   if (retval == 0) {
     return 0;
   } else {
